@@ -1,5 +1,5 @@
 '''gorpy: Good Old Regex and Python
-This is a grep/sed/ls/mv tool for Python 3.6-3.9 that includes:
+This is a grep/sed/ls/renaming tool for Python 3.6-3.9 that includes:
     * piping syntax, 
     * a built-in jsonpath implementation for searching and manipulating JSON/YAML
         documents, comparable to jsonpath_ng in power and extensibility.
@@ -19,12 +19,11 @@ I envision gorp being most useful as a tool for editing JSON and YAML based on t
     strength of the jsonpath module.
 I also find the ability to automatically open files found convenient.
 '''
-
+__all__ = ['readfiles', 'option_docs', 'utils', 'x_option', 'zip_utils', 'tabular_excel', 'textcache', '__main__', 'pdf_utils', 'k_option_del_files', 'gprint', 'jsonpath', 'extended_programming_file_exts']
 
 from .readfiles import GorpSession, GorpLogger, GorpHandler, FileReader, Orddict
 from .readfiles import helpstring
 from .utils import DEFAULT_OPTIONS, PDF_PAGE_LIMIT, PROMPT_K_OPTION, PROMPT_U_OPTION, U_OPTION_OVERWRITES
-from . import gprint
 from . import jsonpath
 
-__version__ = '0.1.6'
\ No newline at end of file
+__version__ = '0.2.4'
\ No newline at end of file
