@@ -8,6 +8,7 @@ option_descriptions = {
 "docx": "-docx (read text of Word documents)",
 "e": "-e (read a list of filenames from a JSON or YAML file)",
 "f": "-f(ilenames and directories only)",
+"g": "-g (execute a series of gorp commands written in a text file)",
 "h": "-h (display lines, not files)",
 "i": "-i (case insensitive)",
 "j": "-j (read JSON files as JSON, using gorp.jsonpath)",
@@ -15,12 +16,13 @@ option_descriptions = {
 "l": "-l (list filenames)",
 "m": "-m (get last Modification time; sort files by most recent first)",
 "n": "-n (get paths/line Numbers of results found)",
+"num": "-<integer> (truncate resultset to length <integer>)", 
 "o": "-o (match only entire words)",
 "p": "-p (oPen all files in the final resultset with their default apps)",
 "pdf": "-pdf (read text of PDF files)",
 "q": "-q (get union (Qnion?) of two resultsets)",
 "r": "-r(ecursive search)",
-"s": "-s(izes of files found; sorts files by size)",
+"s": "-s(izes of files found; sorts files by size descending)",
 "t": "-t (number of files found (and total size if -s arg used)",
 "u": "-u(pdate all files or their contents according to some function)",
 "v": "-v (display only things that DON'T match)",
@@ -48,9 +50,18 @@ DEFAULTS.U_OPTION_OVERWRITES determines whether the -u option overwrites files w
 DEFAULTS.PROMPT_U_OPTION determines whether there's an interactive prompt that considers
     each edit on a case-by-case basis.''',
     
+    'e': '''The syntax is "-e <other options> '<regex>' /<fname>.(json|yaml)".
+fname.json (or fname.yaml) should contain a single array of valid filenames
+or a dict with valid filenames as keys. A typical use of the -e option would
+be to first dump a bunch of filenames into a json/yaml file with the -w option
+and then read it in the future with the -e option.''',
+    
     'f': f'''This option filters filenames, and ignores filenames with 
 extensions not in the following list:
 {gprint(textTypeFiles, str)}''',
+
+    'g': '''The syntax for the -g option is "python -m gorp -g <text file name>". 
+This option can only be used from the command line.''',
     
     'docx': "Gets the text only. No formatting information is extracted.",
     
@@ -77,6 +88,11 @@ DEFAULTS.ALLOW_REMOVE_TREES determines whether the -k option can be used to dele
 DEFAULTS.PROMPT_K_OPTION determines whether the user can see an interactive prompt and
     decide on a case-by-case basis which files and directories they want to delete.''',
     
+    'num': '''The integer can be positive or negative. For example, 
+"-2 <query>" would get the first two files alphabetically that satisfy <query>,
+"-3 -s <query>" would get the three LARGEST files that satisfy <query>, and
+"--3 -s <query>" would get the three SMALLEST files that satisfy <query>.''',
+    
     'j': [
 '''The -j and -y options are based on gorp.jsonpath, and specifically on
 JsonPath(query, json).extract().
@@ -302,7 +318,7 @@ gorp> -j -n '6&&baz&&foo' /bad_json.json # WHOOPS! The '&&' for bundling conditi
                     # works if we use the 'zz' flag to invoke fuzzy key matching.
 Traceback (most recent call last)
 ...
-gorp.jsonpath.JsonPathError: When not in fuzzy_keys mode, only IntRange slicers and ints are allowed as key tests.''',
+gorp.jsonpath.aggregate.JsonPathError: When not in fuzzy_keys mode, only IntRange slicers and ints are allowed as key tests.''',
 
 '''############
 ## GlobalConstraints FOR ALLOWING COMPARISONS OF TWO OR MORE KEY-VALUE PAIRS
@@ -399,6 +415,52 @@ gorp> -j -n '..~~@zz^(?i)[a-z]+\d$~~^^' /bad_json.json
         None
         ]
     }
+}''',
+
+'''############
+## CALCULATING AGGREGATE FUNCTIONS AT VARIOUS LEVELS OF GRANULARITY
+############
+Consider a new JSON file, baseball.json.
+{'foo':
+    {'alice': 
+        {'hits': [3, 4, 2, 5], 'at-bats': [4, 3, 3, 6]},
+     'bob': 
+        {'hits': [-2, 0, 4, 6], 'at-bats': [1, 3, 5, 6]}
+    },
+'bar': 
+    {'carol': 
+        {'hits': [7, 3, 0, 5], 'at-bats': [8, 4, 6, 6]},
+     'dave': 
+        {'hits': [1, 0, 4, 10], 'at-bats': [1, 3, 6, 11]}
+    }
+}
+gorp> -j -n 'zz~~@~~@.*AGG sum BY :' /baseball.json
+    # the "AGG sum BY :" at the end of the query means that we sum up all the
+    # numbers we found, grouped by each distinct path (":" means all of it).
+    # So we're aggregating hits and at-bats separately by player-team combo.
+1 files
+{
+'C:\\Users\\mjols\\Python39\\gorpy\\gorp\\testDir\\walnut\\baseball.json':
+    {
+    ('bar', 'carol', 'at-bats'): 24,
+    ('bar', 'carol', 'hits'): 15,
+    ('bar', 'dave', 'at-bats'): 21,
+    ('bar', 'dave', 'hits'): 15,
+    ('foo', 'alice', 'at-bats'): 16,
+    ('foo', 'alice', 'hits'): 14,
+    ('foo', 'bob', 'at-bats'): 15,
+    ('foo', 'bob', 'hits'): 8
+    }
+}
+gorp> -j -n 'zz~~@~~@hitsAGG sum(x)/len(x) BY 0' /baseball.json
+    # average hits grouped by team (could use 'avg' instead of 'sum(x)/len(x)')
+1 files
+{
+'C:\\Users\\mjols\\Python39\\gorpy\\gorp\\testDir\\walnut\\baseball.json':
+    {
+    ('bar',): 3.75,
+    ('foo',): 2.75
+    }
 }
 ~~~~~~~~~~~~~~~
 END OF EXAMPLES
@@ -412,6 +474,7 @@ We've at least touched on all of the key features, the most important of which a
     - 'gg' to create GlobalConstraints that allow comparisons of multiple values in the
         same iterable.
     - '~~@' and '~~^' to get children and parents, respectively .
-    - '!!' to reverse the selectivity of key and value matching.'''
+    - '!!' to reverse the selectivity of key and value matching.
+    - 'AGG<function>BY<int/slice>' to calculate aggregates with grouping.'''
     ]
 }
\ No newline at end of file
