@@ -20,6 +20,9 @@
 - You can reset all the default behaviors to their original values with 
     "DEFAULTS.reset()".
 - You can set a DEFAULT option as well, e.g. "DEFAULTS.PROMPT_K_OPTION = True"
+- Finally, not all text files will be read by default by gorp. To change which
+    file extensions are treated as text files, see site-packages/gorp/utils.py.
+- "gorp doc f" will show a list of "text-type-files".
 '''
 from .utils import *
 from .gprint import gprint
@@ -299,7 +302,7 @@ GorpHandlers should only be created by a GorpSession.'''
         GorpLogger.info(f"In GorpHandler.__init__, parsedQuery = {self.parsedQuery}")
         self.readers = []
         self.level = 0
-        self.options = [set(re.split("\s*-", x[0].strip().lower())[1:]) for x in self.parsedQuery]
+        self.options = [set(re.findall("(?<=-)\S+", x[0].strip().lower())) for x in self.parsedQuery]
         self.all_options = set(opt for opts in self.options for opt in opts)
         self.regexes = [x[1].replace('\\\'', '\'') for x in self.parsedQuery]
         if resultset is None:
@@ -420,6 +423,7 @@ down the resultset'''
                     json.dump(self.resultset,f, indent = 4)
         if self.z: # collect all files into a ZIP file at target location
             import zipfile
+            from gorp.zip_utils import make_relpaths
             write_to_name = increment_name(ext_checker(self.parsedQuery[-1][1], 'zip'))
             with zipfile.ZipFile(write_to_name, 
                                  mode = 'w', # 'x' mode is like 'w', but raises error
@@ -428,7 +432,15 @@ down the resultset'''
                                  # ZIP_STORED is default; it means no compression at all
                                  # ZIP_LZMA and ZIP_BZIP2 may be good alternatives
                                  ) as zf:
-                for fname in self.resultset:
+                if len(self.resultset) > 1:
+                    files = make_relpaths(self.resultset)
+                elif len(self.resultset) == 1:
+                    files = [os.path.basename(f) for f in self.resultset]
+                    # make_relpaths(files) finds the longest path shared by
+                    # all paths in files, and truncates all those files to
+                    # remove the redundant common part.
+                    # But if there's only one file, this chops off everything.
+                for fname in files:
                     zf.write(fname)
         if not (self.w or self.k or self.p or self.t or self.u):
             if self.s or self.m:
@@ -691,6 +703,7 @@ class FileReader:
                 self.dirName = files
                 self.files = generateFileSet(files, self.d, self.r)
             else:
+                self.dirName = ''
                 if self.e: 
                     # 'e' option means you read files in from a JSON/YAML file
                     use_yaml = get_ext(files) in {'yml', 'yaml'}
@@ -747,9 +760,17 @@ class FileReader:
             if isinstance(self.resultset, dict):
                 short_results = Orddict()
                 for ii, elt in enumerate(self.resultset):
-                    if ii == new_result_len:
-                        break
-                    short_results[elt] = self.resultset[elt]
+                    if new_result_len >= 0:
+                        # add the first new_result_len elements of the
+                        # resultset, when iterated through in the default order
+                        if ii == new_result_len:
+                            break
+                        short_results[elt] = self.resultset[elt]
+                    else:
+                        # add the last new_result_len elements of the the
+                        # resultset, when iterated through in the default order
+                        if ii >= len(self.resultset) + new_result_len:
+                            short_results[elt] = self.resultset[elt]
                 self.resultset = short_results
             else:
                 self.resultset = self.resultset[:new_result_len]
@@ -757,7 +778,10 @@ class FileReader:
             sizes = [(f, last_mod_time(f, True), os.path.getsize(f)) for f in self.resultset]
             sizes.sort(key = lambda x: x[2], reverse = True)
             if new_result_len is not None: # truncate after sorting to get largest
-                sizes = sizes[:new_result_len]
+                if new_result_len < 0:
+                    sizes = sizes[new_result_len:]
+                else:
+                    sizes = sizes[:new_result_len]
             self.summary = [f"{len(sizes)} files", format_bytes(sum(x[-1] for x in sizes))]
             self.resultset = Orddict([(f, (str(mod), format_bytes(siz))) for f,mod,siz in sizes]) 
             # Orddict is just a normal dict for Python 3.7+, else a collections.OrderedDict
@@ -765,14 +789,20 @@ class FileReader:
             modtime_d = [(f,last_mod_time(f,True)) for f in self.resultset]
             modtime_d.sort(key=lambda x: x[1], reverse=True)
             if new_result_len is not None: # truncate after sorting to get most recent
-                modtime_d = modtime_d[:new_result_len]
+                if new_result_len < 0: # get OLDEST files
+                    modtime_d = modtime_d[new_result_len:]
+                else: # get NEWEST FILES
+                    modtime_d = modtime_d[:new_result_len]
             self.resultset = Orddict((f, str(mod)) for f, mod in modtime_d)
             self.summary = f"{len(self.resultset)} files"
         elif self.s: # get size; not last mod time
             sizes = [(f, os.path.getsize(f)) for f in self.resultset]
             sizes.sort(key = lambda x: x[1], reverse = True)
             if new_result_len is not None: # truncate after sorting to get largest
-                sizes = sizes[:new_result_len]
+                if new_result_len < 0: # get the new_result_len SMALLEST files
+                    sizes = sizes[new_result_len:]
+                else: # get new_result_len LARGEST files
+                    sizes = sizes[:new_result_len]
             self.summary = [f"{len(sizes)} files", format_bytes(sum(x[-1] for x in sizes))]
             self.resultset = Orddict([(f, format_bytes(siz)) for f,siz in sizes])
         else:
@@ -896,7 +926,12 @@ class FileReader:
                     return
                 del text
                 self.jsonpath.add_json(docs)
-                path_obj_map = self.jsonpath.extract()
+                if self.jsonpath.aggregator is not None:
+                    # use the aggregate function of jsonpath to aggregate the
+                    # values in the json, e.g., by summing them
+                    path_obj_map = self.jsonpath.aggregate()
+                else:
+                    path_obj_map = self.jsonpath.extract()
                 if path_obj_map:
                     self.resultset.setdefault(file, {})
                     self.resultset[file].update(path_obj_map) 
