@@ -4,6 +4,9 @@ from gorp.test import test_textcache
 from gorp.test import test_option_combos
 from gorp.test import test_pdf_option
 from gorp.test import test_q_option
+from gorp.test import test_e_w_options
+from gorp.test import test_zip
+from gorp.test import test_x_option
 import doctest
 
 def main():
@@ -20,6 +23,12 @@ def main():
     test_pdf_option.main()
     print("===============\nTesting the q option for unioning resultsets")
     test_q_option.main()
+    print("===============\nTesting e and w options for writing/reading resultsets to/from file")
+    test_e_w_options.main()
+    print("===============\nTesting -z option for zipping files together")
+    test_zip.main()
+    print("===============\nTesting -x option for reading XML and HTML")
+    test_x_option.main()
     
 if __name__ == '__main__':
     main()
\ No newline at end of file
